@@ -26,7 +26,6 @@ import (
 	"github.com/go-delve/delve/pkg/terminal"
 	"github.com/go-delve/delve/service/dap"
 	"github.com/go-delve/delve/service/dap/daptest"
-	"github.com/go-delve/delve/service/debugger"
 	"github.com/go-delve/delve/service/rpc2"
 	godap "github.com/google/go-dap"
 	"golang.org/x/tools/go/packages"
@@ -204,7 +203,7 @@ func testOutput(t *testing.T, dlvbin, output string, delveCmds []string) (stdout
 	return
 }
 
-func getDlvBin(t *testing.T) (string, string) {
+func getDlvBin(t *testing.T) string {
 	// In case this was set in the environment
 	// from getDlvBinEBPF lets clear it here so
 	// we can ensure we don't get build errors
@@ -217,17 +216,12 @@ func getDlvBin(t *testing.T) (string, string) {
 	return getDlvBinInternal(t, tags)
 }
 
-func getDlvBinEBPF(t *testing.T) (string, string) {
+func getDlvBinEBPF(t *testing.T) string {
 	return getDlvBinInternal(t, "-tags", "ebpf")
 }
 
-func getDlvBinInternal(t *testing.T, goflags ...string) (string, string) {
-	tmpdir, err := ioutil.TempDir("", "TestDlv")
-	if err != nil {
-		t.Fatal(err)
-	}
-
-	dlvbin := filepath.Join(tmpdir, "dlv.exe")
+func getDlvBinInternal(t *testing.T, goflags ...string) string {
+	dlvbin := filepath.Join(t.TempDir(), "dlv.exe")
 	args := append([]string{"build", "-o", dlvbin}, goflags...)
 	args = append(args, "github.com/go-delve/delve/cmd/dlv")
 
@@ -236,16 +230,15 @@ func getDlvBinInternal(t *testing.T, goflags ...string) (string, string) {
 		t.Fatalf("go build -o %v github.com/go-delve/delve/cmd/dlv: %v\n%s", dlvbin, err, string(out))
 	}
 
-	return dlvbin, tmpdir
+	return dlvbin
 }
 
 // TestOutput verifies that the debug executable is created in the correct path
 // and removed after exit.
 func TestOutput(t *testing.T) {
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
-	for _, output := range []string{"", "myownname", filepath.Join(tmpdir, "absolute.path")} {
+	for _, output := range []string{"__debug_bin", "myownname", filepath.Join(t.TempDir(), "absolute.path")} {
 		testOutput(t, dlvbin, output, []string{"exit"})
 
 		const hello = "hello world!"
@@ -260,8 +253,7 @@ func TestOutput(t *testing.T) {
 func TestContinue(t *testing.T) {
 	const listenAddr = "127.0.0.1:40573"
 
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	buildtestdir := filepath.Join(protest.FindFixturesDir(), "buildtest")
 	cmd := exec.Command(dlvbin, "debug", "--headless", "--continue", "--accept-multiclient", "--listen", listenAddr)
@@ -289,64 +281,11 @@ func TestContinue(t *testing.T) {
 	cmd.Wait()
 }
 
-// TestChildProcessExitWhenNoDebugInfo verifies that the child process exits when dlv launch the binary without debug info
-func TestChildProcessExitWhenNoDebugInfo(t *testing.T) {
-	noDebugFlags := protest.LinkStrip
-	// -s doesn't strip symbols on Mac, use -w instead
-	if runtime.GOOS == "darwin" {
-		noDebugFlags = protest.LinkDisableDWARF
-	}
-
-	if _, err := exec.LookPath("ps"); err != nil {
-		t.Skip("test skipped, `ps` not found")
-	}
-
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
-
-	fix := protest.BuildFixture("http_server", noDebugFlags)
-
-	// dlv exec the binary file and expect error.
-	out, err := exec.Command(dlvbin, "exec", "--headless", "--log", fix.Path).CombinedOutput()
-	t.Log(string(out))
-	if err == nil {
-		t.Fatalf("Expected err when launching the binary without debug info, but got nil")
-	}
-	//  Test only for dlv's prefix of the error like "could not launch process: could not open debug info"
-	if !strings.Contains(string(out), "could not launch process") || !strings.Contains(string(out), debugger.NoDebugWarning) {
-		t.Fatalf("Expected logged error 'could not launch process: ... - %s'", debugger.NoDebugWarning)
-	}
-
-	// search the running process named fix.Name
-	cmd := exec.Command("ps", "-aux")
-	stdout, err := cmd.StdoutPipe()
-	assertNoError(err, t, "stdout pipe")
-	defer stdout.Close()
-
-	assertNoError(cmd.Start(), t, "start `ps -aux`")
-
-	var foundFlag bool
-	scan := bufio.NewScanner(stdout)
-	for scan.Scan() {
-		t.Log(scan.Text())
-		if strings.Contains(scan.Text(), fix.Name) {
-			foundFlag = true
-			break
-		}
-	}
-	cmd.Wait()
-
-	if foundFlag {
-		t.Fatalf("Expected child process exited, but found it running")
-	}
-}
-
 // TestRedirect verifies that redirecting stdin works
 func TestRedirect(t *testing.T) {
 	const listenAddr = "127.0.0.1:40573"
 
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	catfixture := filepath.Join(protest.FindFixturesDir(), "cat.go")
 	cmd := exec.Command(dlvbin, "debug", "--headless", "--continue", "--accept-multiclient", "--listen", listenAddr, "-r", catfixture, catfixture)
@@ -439,12 +378,10 @@ func TestGeneratedDoc(t *testing.T) {
 	checkAutogenDoc(t, "Documentation/cli/README.md", "_scripts/gen-cli-docs.go", generatedBuf.Bytes())
 
 	// Checks gen-usage-docs.go
-	tempDir, err := ioutil.TempDir(os.TempDir(), "test-gen-doc")
-	assertNoError(err, t, "TempDir")
-	defer protest.SafeRemoveAll(tempDir)
+	tempDir := t.TempDir()
 	cmd := exec.Command("go", "run", "_scripts/gen-usage-docs.go", tempDir)
 	cmd.Dir = projectRoot()
-	err = cmd.Run()
+	err := cmd.Run()
 	assertNoError(err, t, "go run _scripts/gen-usage-docs.go")
 	entries, err := ioutil.ReadDir(tempDir)
 	assertNoError(err, t, "ReadDir")
@@ -468,6 +405,7 @@ func TestGeneratedDoc(t *testing.T) {
 	checkAutogenDoc(t, "Documentation/backend_test_health.md", "go run _scripts/gen-backend_test_health.go", runScript("_scripts/gen-backend_test_health.go", "-"))
 	checkAutogenDoc(t, "pkg/terminal/starbind/starlark_mapping.go", "'go generate' inside pkg/terminal/starbind", runScript("_scripts/gen-starlark-bindings.go", "go", "-"))
 	checkAutogenDoc(t, "Documentation/cli/starlark.md", "'go generate' inside pkg/terminal/starbind", runScript("_scripts/gen-starlark-bindings.go", "doc/dummy", "Documentation/cli/starlark.md"))
+	checkAutogenDoc(t, "Documentation/faq.md", "'go run _scripts/gen-faq-toc.go Documentation/faq.md Documentation/faq.md'", runScript("_scripts/gen-faq-toc.go", "Documentation/faq.md", "-"))
 	if goversion.VersionAfterOrEqual(runtime.Version(), 1, 18) {
 		checkAutogenDoc(t, "_scripts/rtype-out.txt", "go run _scripts/rtype.go report _scripts/rtype-out.txt", runScript("_scripts/rtype.go", "report"))
 		runScript("_scripts/rtype.go", "check")
@@ -475,8 +413,7 @@ func TestGeneratedDoc(t *testing.T) {
 }
 
 func TestExitInInit(t *testing.T) {
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	buildtestdir := filepath.Join(protest.FindFixturesDir(), "buildtest")
 	exitInit := filepath.Join(protest.FindFixturesDir(), "exit.init")
@@ -676,8 +613,7 @@ func TestTypecheckRPC(t *testing.T) {
 func TestDAPCmd(t *testing.T) {
 	const listenAddr = "127.0.0.1:40575"
 
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	cmd := exec.Command(dlvbin, "dap", "--log-output=dap", "--log", "--listen", listenAddr)
 	stdout, err := cmd.StdoutPipe()
@@ -723,58 +659,6 @@ func TestDAPCmd(t *testing.T) {
 	cmd.Wait()
 }
 
-func TestDAPCmdWithNoDebugBinary(t *testing.T) {
-	const listenAddr = "127.0.0.1:40579"
-
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
-
-	cmd := exec.Command(dlvbin, "dap", "--log", "--listen", listenAddr)
-	stdout, err := cmd.StdoutPipe()
-	assertNoError(err, t, "stdout pipe")
-	defer stdout.Close()
-	stderr, err := cmd.StderrPipe()
-	assertNoError(err, t, "stderr pipe")
-	defer stderr.Close()
-	assertNoError(cmd.Start(), t, "start dap instance")
-
-	scanOut := bufio.NewScanner(stdout)
-	scanErr := bufio.NewScanner(stderr)
-	// Wait for the debug server to start
-	scanOut.Scan()
-	listening := "DAP server listening at: " + listenAddr
-	if scanOut.Text() != listening {
-		cmd.Process.Kill() // release the port
-		t.Fatalf("Unexpected stdout:\ngot  %q\nwant %q", scanOut.Text(), listening)
-	}
-	go func() { // Capture logging
-		for scanErr.Scan() {
-			t.Log(scanErr.Text())
-		}
-	}()
-
-	// Exec the stripped debuggee and expect things to fail
-	noDebugFlags := protest.LinkStrip
-	// -s doesn't strip symbols on Mac, use -w instead
-	if runtime.GOOS == "darwin" {
-		noDebugFlags = protest.LinkDisableDWARF
-	}
-	fixture := protest.BuildFixture("increment", noDebugFlags)
-	go func() {
-		for scanOut.Scan() {
-			t.Errorf("Unexpected stdout: %s", scanOut.Text())
-		}
-	}()
-	client := daptest.NewClient(listenAddr)
-	client.LaunchRequest("exec", fixture.Path, false)
-	client.ExpectErrorResponse(t)
-	client.DisconnectRequest()
-	client.ExpectDisconnectResponse(t)
-	client.ExpectTerminatedEvent(t)
-	client.Close()
-	cmd.Wait()
-}
-
 func newDAPRemoteClient(t *testing.T, addr string, isDlvAttach bool, isMulti bool) *daptest.Client {
 	c := daptest.NewClient(addr)
 	c.AttachRequest(map[string]interface{}{"mode": "remote", "stopOnEntry": true})
@@ -792,8 +676,7 @@ func newDAPRemoteClient(t *testing.T, addr string, isDlvAttach bool, isMulti boo
 func TestRemoteDAPClient(t *testing.T) {
 	const listenAddr = "127.0.0.1:40576"
 
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	buildtestdir := filepath.Join(protest.FindFixturesDir(), "buildtest")
 	cmd := exec.Command(dlvbin, "debug", "--headless", "--log-output=dap", "--log", "--listen", listenAddr)
@@ -846,8 +729,7 @@ func closeDAPRemoteMultiClient(t *testing.T, c *daptest.Client, expectStatus str
 func TestRemoteDAPClientMulti(t *testing.T) {
 	const listenAddr = "127.0.0.1:40577"
 
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	buildtestdir := filepath.Join(protest.FindFixturesDir(), "buildtest")
 	cmd := exec.Command(dlvbin, "debug", "--headless", "--accept-multiclient", "--log-output=debugger", "--log", "--listen", listenAddr)
@@ -914,8 +796,7 @@ func TestRemoteDAPClientMulti(t *testing.T) {
 func TestRemoteDAPClientAfterContinue(t *testing.T) {
 	const listenAddr = "127.0.0.1:40578"
 
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	fixture := protest.BuildFixture("loopprog", 0)
 	cmd := exec.Command(dlvbin, "exec", fixture.Path, "--headless", "--continue", "--accept-multiclient", "--log-output=debugger,dap", "--log", "--listen", listenAddr)
@@ -976,8 +857,7 @@ func TestDAPCmdWithClient(t *testing.T) {
 	}
 	defer listener.Close()
 
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	cmd := exec.Command(dlvbin, "dap", "--log-output=dap", "--log", "--client-addr", listener.Addr().String())
 	buf := &bytes.Buffer{}
@@ -1011,13 +891,12 @@ func TestDAPCmdWithClient(t *testing.T) {
 }
 
 func TestTrace(t *testing.T) {
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	expected := []byte("> goroutine(1): main.foo(99, 9801)\n>> goroutine(1): => (9900)\n")
 
 	fixtures := protest.FindFixturesDir()
-	cmd := exec.Command(dlvbin, "trace", "--output", filepath.Join(tmpdir, "__debug"), filepath.Join(fixtures, "issue573.go"), "foo")
+	cmd := exec.Command(dlvbin, "trace", "--output", filepath.Join(t.TempDir(), "__debug"), filepath.Join(fixtures, "issue573.go"), "foo")
 	rdr, err := cmd.StderrPipe()
 	assertNoError(err, t, "stderr pipe")
 	defer rdr.Close()
@@ -1035,14 +914,32 @@ func TestTrace(t *testing.T) {
 	cmd.Wait()
 }
 
-func TestTraceMultipleGoroutines(t *testing.T) {
-	if runtime.GOOS == "freebsd" {
-		//TODO(aarzilli): investigate further when the FreeBSD backend is more stable.
-		t.Skip("temporarily disabled due to issues with FreeBSD in Delve and Go")
-	}
+func TestTrace2(t *testing.T) {
+	dlvbin := getDlvBin(t)
 
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	expected := []byte("> goroutine(1): main.callme(2)\n>> goroutine(1): => (4)\n")
+
+	fixtures := protest.FindFixturesDir()
+	cmd := exec.Command(dlvbin, "trace", "--output", filepath.Join(t.TempDir(), "__debug"), filepath.Join(fixtures, "traceprog.go"), "callme")
+	rdr, err := cmd.StderrPipe()
+	assertNoError(err, t, "stderr pipe")
+	defer rdr.Close()
+
+	cmd.Dir = filepath.Join(fixtures, "buildtest")
+
+	assertNoError(cmd.Start(), t, "running trace")
+
+	output, err := ioutil.ReadAll(rdr)
+	assertNoError(err, t, "ReadAll")
+
+	if !bytes.Contains(output, expected) {
+		t.Fatalf("expected:\n%s\ngot:\n%s", string(expected), string(output))
+	}
+	assertNoError(cmd.Wait(), t, "cmd.Wait()")
+}
+
+func TestTraceMultipleGoroutines(t *testing.T) {
+	dlvbin := getDlvBin(t)
 
 	// TODO(derekparker) this test has to be a bit vague to avoid flakyness.
 	// I think a future improvement could be to use regexp captures to match the
@@ -1051,7 +948,7 @@ func TestTraceMultipleGoroutines(t *testing.T) {
 	expected2 := []byte("=> (0)\n")
 
 	fixtures := protest.FindFixturesDir()
-	cmd := exec.Command(dlvbin, "trace", "--output", filepath.Join(tmpdir, "__debug"), filepath.Join(fixtures, "goroutines-trace.go"), "callme")
+	cmd := exec.Command(dlvbin, "trace", "--output", filepath.Join(t.TempDir(), "__debug"), filepath.Join(fixtures, "goroutines-trace.go"), "callme")
 	rdr, err := cmd.StderrPipe()
 	assertNoError(err, t, "stderr pipe")
 	defer rdr.Close()
@@ -1081,8 +978,7 @@ func TestTracePid(t *testing.T) {
 		}
 	}
 
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	expected := []byte("goroutine(1): main.A()\n>> goroutine(1): => ()\n")
 
@@ -1115,14 +1011,13 @@ func TestTracePid(t *testing.T) {
 }
 
 func TestTraceBreakpointExists(t *testing.T) {
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	fixtures := protest.FindFixturesDir()
 	// We always set breakpoints on some runtime functions at startup, so this would return with
 	// a breakpoints exists error.
 	// TODO: Perhaps we shouldn't be setting these default breakpoints in trace mode, however.
-	cmd := exec.Command(dlvbin, "trace", "--output", filepath.Join(tmpdir, "__debug"), filepath.Join(fixtures, "issue573.go"), "runtime.*")
+	cmd := exec.Command(dlvbin, "trace", "--output", filepath.Join(t.TempDir(), "__debug"), filepath.Join(fixtures, "issue573.go"), "runtime.*")
 	rdr, err := cmd.StderrPipe()
 	assertNoError(err, t, "stderr pipe")
 	defer rdr.Close()
@@ -1142,11 +1037,10 @@ func TestTraceBreakpointExists(t *testing.T) {
 }
 
 func TestTracePrintStack(t *testing.T) {
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	fixtures := protest.FindFixturesDir()
-	cmd := exec.Command(dlvbin, "trace", "--output", filepath.Join(tmpdir, "__debug"), "--stack", "2", filepath.Join(fixtures, "issue573.go"), "foo")
+	cmd := exec.Command(dlvbin, "trace", "--output", filepath.Join(t.TempDir(), "__debug"), "--stack", "2", filepath.Join(fixtures, "issue573.go"), "foo")
 	rdr, err := cmd.StderrPipe()
 	assertNoError(err, t, "stderr pipe")
 	defer rdr.Close()
@@ -1182,13 +1076,12 @@ func TestTraceEBPF(t *testing.T) {
 		t.Skip("test must be run as root")
 	}
 
-	dlvbin, tmpdir := getDlvBinEBPF(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBinEBPF(t)
 
 	expected := []byte("> (1) main.foo(99, 9801)\n=> \"9900\"")
 
 	fixtures := protest.FindFixturesDir()
-	cmd := exec.Command(dlvbin, "trace", "--ebpf", "--output", filepath.Join(tmpdir, "__debug"), filepath.Join(fixtures, "issue573.go"), "foo")
+	cmd := exec.Command(dlvbin, "trace", "--ebpf", "--output", filepath.Join(t.TempDir(), "__debug"), filepath.Join(fixtures, "issue573.go"), "foo")
 	rdr, err := cmd.StderrPipe()
 	assertNoError(err, t, "stderr pipe")
 	defer rdr.Close()
@@ -1222,8 +1115,7 @@ func TestTraceEBPF2(t *testing.T) {
 		t.Skip("test must be run as root")
 	}
 
-	dlvbin, tmpdir := getDlvBinEBPF(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBinEBPF(t)
 
 	expected := []byte(`> (1) main.callme(10)
 > (1) main.callme(9)
@@ -1249,7 +1141,55 @@ func TestTraceEBPF2(t *testing.T) {
 => "100"`)
 
 	fixtures := protest.FindFixturesDir()
-	cmd := exec.Command(dlvbin, "trace", "--ebpf", "--output", filepath.Join(tmpdir, "__debug"), filepath.Join(fixtures, "ebpf_trace.go"), "main.callme")
+	cmd := exec.Command(dlvbin, "trace", "--ebpf", "--output", filepath.Join(t.TempDir(), "__debug"), filepath.Join(fixtures, "ebpf_trace.go"), "main.callme")
+	rdr, err := cmd.StderrPipe()
+	assertNoError(err, t, "stderr pipe")
+	defer rdr.Close()
+
+	assertNoError(cmd.Start(), t, "running trace")
+
+	output, err := ioutil.ReadAll(rdr)
+	assertNoError(err, t, "ReadAll")
+
+	if !bytes.Contains(output, expected) {
+		t.Fatalf("expected:\n%s\ngot:\n%s", string(expected), string(output))
+	}
+	cmd.Wait()
+}
+
+func TestTraceEBPF3(t *testing.T) {
+	if os.Getenv("CI") == "true" {
+		t.Skip("cannot run test in CI, requires kernel compiled with btf support")
+	}
+	if runtime.GOOS != "linux" || runtime.GOARCH != "amd64" {
+		t.Skip("not implemented on non linux/amd64 systems")
+	}
+	if !goversion.VersionAfterOrEqual(runtime.Version(), 1, 16) {
+		t.Skip("requires at least Go 1.16 to run test")
+	}
+	usr, err := user.Current()
+	if err != nil {
+		t.Fatal(err)
+	}
+	if usr.Uid != "0" {
+		t.Skip("test must be run as root")
+	}
+
+	dlvbin := getDlvBinEBPF(t)
+
+	expected := []byte(`> (1) main.tracedFunction(0)
+> (1) main.tracedFunction(1)
+> (1) main.tracedFunction(2)
+> (1) main.tracedFunction(3)
+> (1) main.tracedFunction(4)
+> (1) main.tracedFunction(5)
+> (1) main.tracedFunction(6)
+> (1) main.tracedFunction(7)
+> (1) main.tracedFunction(8)
+> (1) main.tracedFunction(9)`)
+
+	fixtures := protest.FindFixturesDir()
+	cmd := exec.Command(dlvbin, "trace", "--ebpf", "--output", filepath.Join(t.TempDir(), "__debug"), filepath.Join(fixtures, "ebpf_trace2.go"), "main.traced")
 	rdr, err := cmd.StderrPipe()
 	assertNoError(err, t, "stderr pipe")
 	defer rdr.Close()
@@ -1266,28 +1206,39 @@ func TestTraceEBPF2(t *testing.T) {
 }
 
 func TestDlvTestChdir(t *testing.T) {
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	fixtures := protest.FindFixturesDir()
-	cmd := exec.Command(dlvbin, "--allow-non-terminal-interactive=true", "test", filepath.Join(fixtures, "buildtest"), "--", "-test.v")
-	cmd.Stdin = strings.NewReader("continue\nexit\n")
-	out, err := cmd.CombinedOutput()
-	if err != nil {
-		t.Fatalf("error executing Delve: %v", err)
-	}
-	t.Logf("output: %q", out)
 
-	p, _ := filepath.Abs(filepath.Join(fixtures, "buildtest"))
-	tgt := "current directory: " + p
-	if !strings.Contains(string(out), tgt) {
-		t.Errorf("output did not contain expected string %q", tgt)
+	dotest := func(testargs []string) {
+		t.Helper()
+
+		args := []string{"--allow-non-terminal-interactive=true", "test"}
+		args = append(args, testargs...)
+		args = append(args, "--", "-test.v")
+		t.Logf("dlv test %s", args)
+		cmd := exec.Command(dlvbin, args...)
+		cmd.Stdin = strings.NewReader("continue\nexit\n")
+		out, err := cmd.CombinedOutput()
+		if err != nil {
+			t.Fatalf("error executing Delve: %v", err)
+		}
+		t.Logf("output: %q", out)
+
+		p, _ := filepath.Abs(filepath.Join(fixtures, "buildtest"))
+		tgt := "current directory: " + p
+		if !strings.Contains(string(out), tgt) {
+			t.Errorf("output did not contain expected string %q", tgt)
+		}
 	}
+
+	dotest([]string{filepath.Join(fixtures, "buildtest")})
+	files, _ := filepath.Glob(filepath.Join(fixtures, "buildtest", "*.go"))
+	dotest(files)
 }
 
 func TestVersion(t *testing.T) {
-	dlvbin, tmpdir := getDlvBin(t)
-	defer os.RemoveAll(tmpdir)
+	dlvbin := getDlvBin(t)
 
 	got, err := exec.Command(dlvbin, "version", "-v").CombinedOutput()
 	if err != nil {
@@ -1305,10 +1256,6 @@ func TestStaticcheck(t *testing.T) {
 	if err != nil {
 		t.Skip("staticcheck not installed")
 	}
-	if goversion.VersionAfterOrEqual(runtime.Version(), 1, 20) {
-		//TODO(aarzilli): remove this when there is a version of staticcheck that can support go1.20
-		t.Skip("staticcheck does not support go1.20 currently")
-	}
 	// default checks minus SA1019 which complains about deprecated identifiers, which change between versions of Go.
 	args := []string{"-tests=false", "-checks=all,-SA1019,-ST1000,-ST1003,-ST1016,-S1021,-ST1023", "github.com/go-delve/delve/..."}
 	// * SA1019 is disabled because new deprecations get added on every version
@@ -1325,3 +1272,39 @@ func TestStaticcheck(t *testing.T) {
 	out, _ := cmd.CombinedOutput()
 	checkAutogenDoc(t, "_scripts/staticcheck-out.txt", fmt.Sprintf("staticcheck %s > _scripts/staticcheck-out.txt", strings.Join(args, " ")), out)
 }
+
+func TestDefaultBinary(t *testing.T) {
+	// Check that when delve is run twice in the same directory simultaneously
+	// it will pick different default output binary paths.
+	dlvbin := getDlvBin(t)
+	fixture := filepath.Join(protest.FindFixturesDir(), "testargs.go")
+
+	startOne := func() (io.WriteCloser, func() error, *bytes.Buffer) {
+		cmd := exec.Command(dlvbin, "debug", "--allow-non-terminal-interactive=true", fixture, "--", "test")
+		stdin, _ := cmd.StdinPipe()
+		stdoutBuf := new(bytes.Buffer)
+		cmd.Stdout = stdoutBuf
+
+		assertNoError(cmd.Start(), t, "dlv debug")
+		return stdin, cmd.Wait, stdoutBuf
+	}
+
+	stdin1, wait1, stdoutBuf1 := startOne()
+	defer stdin1.Close()
+
+	stdin2, wait2, stdoutBuf2 := startOne()
+	defer stdin2.Close()
+
+	fmt.Fprintf(stdin1, "continue\nquit\n")
+	fmt.Fprintf(stdin2, "continue\nquit\n")
+
+	wait1()
+	wait2()
+
+	out1, out2 := stdoutBuf1.String(), stdoutBuf2.String()
+	t.Logf("%q", out1)
+	t.Logf("%q", out2)
+	if out1 == out2 {
+		t.Errorf("outputs match")
+	}
+}
