@@ -96,7 +96,7 @@ type Breaklet struct {
 	// the return value will determine if the breaklet should be considered
 	// active.
 	// The callback can have side-effects.
-	callback func(th Thread) bool
+	callback func(th Thread, p *Target) (bool, error)
 
 	// For WatchOutOfScopeBreakpoints and StackResizeBreakpoints the watchpoint
 	// field contains the watchpoint related to this out of scope sentinel.
@@ -294,12 +294,6 @@ func (bpstate *BreakpointState) checkCond(tgt *Target, breaklet *Breaklet, threa
 			}
 		}
 		active = active && nextDeferOk
-		if active {
-			bpstate.Stepping = true
-			if breaklet.Kind == StepBreakpoint {
-				bpstate.SteppingInto = true
-			}
-		}
 
 	case WatchOutOfScopeBreakpoint:
 		if breaklet.checkPanicCall {
@@ -319,10 +313,24 @@ func (bpstate *BreakpointState) checkCond(tgt *Target, breaklet *Breaklet, threa
 
 	if active {
 		if breaklet.callback != nil {
-			active = breaklet.callback(thread)
+			var err error
+			active, err = breaklet.callback(thread, tgt)
+			if err != nil && bpstate.CondError == nil {
+				bpstate.CondError = err
+			}
 		}
 		bpstate.Active = active
 	}
+
+	if bpstate.Active {
+		switch breaklet.Kind {
+		case NextBreakpoint, NextDeferBreakpoint:
+			bpstate.Stepping = true
+		case StepBreakpoint:
+			bpstate.Stepping = true
+			bpstate.SteppingInto = true
+		}
+	}
 }
 
 // checkHitCond evaluates bp's hit condition on thread.
@@ -546,7 +554,7 @@ func (t *Target) setEBPFTracepointOnFunc(fn *Function, goidOffset int64) error {
 	if t.BinInfo().Producer() != "" && goversion.ProducerAfterOrEqual(t.BinInfo().Producer(), 1, 15) {
 		variablesFlags |= reader.VariablesTrustDeclLine
 	}
-	_, l, _ := t.BinInfo().PCToLine(fn.Entry)
+	_, l := t.BinInfo().EntryLineForFunc(fn)
 
 	var args []ebpf.UProbeArgMap
 	varEntries := reader.Variables(dwarfTree, fn.Entry, l, variablesFlags)
