@@ -611,7 +611,7 @@ func TestClientServer_toggleAmendedBreakpoint(t *testing.T) {
 			t.Fatal(err)
 		}
 		if amended.Cond == "" {
-			t.Fatal("breakpoint amendedments not preserved after toggle")
+			t.Fatal("breakpoint amendments not preserved after toggle")
 		}
 	})
 }
@@ -1360,7 +1360,7 @@ func TestIssue355(t *testing.T) {
 }
 
 func TestDisasm(t *testing.T) {
-	// Tests that disassembling by PC, range, and current PC all yeld similar results
+	// Tests that disassembling by PC, range, and current PC all yield similar results
 	// Tests that disassembly by current PC will return a disassembly containing the instruction at PC
 	// Tests that stepping on a calculated CALL instruction will yield a disassembly that contains the
 	// effective destination of the CALL instruction
@@ -1962,7 +1962,7 @@ func TestClientServerConsistentExit(t *testing.T) {
 
 		// Ensure future commands also return the correct exit status.
 		// Previously there was a bug where the command which prompted the
-		// process to exit (continue, next, etc...) would return the corrent
+		// process to exit (continue, next, etc...) would return the current
 		// exit status but subsequent commands would return an incorrect exit
 		// status of 0. To test this we simply repeat the 'next' command and
 		// ensure we get the correct response again.
@@ -2188,7 +2188,7 @@ func TestAncestors(t *testing.T) {
 	defer os.Setenv("GODEBUG", savedGodebug)
 	withTestClient2("testnextprog", t, func(c service.Client) {
 		_, err := c.CreateBreakpoint(&api.Breakpoint{FunctionName: "main.testgoroutine", Line: -1})
-		assertNoError(err, t, "CreateBreakpoin")
+		assertNoError(err, t, "CreateBreakpoint")
 		state := <-c.Continue()
 		assertNoError(state.Err, t, "Continue()")
 		ancestors, err := c.Ancestors(-1, 1000, 1000)
@@ -2259,7 +2259,7 @@ func TestRerecord(t *testing.T) {
 	withTestClient2("testrerecord", t, func(c service.Client) {
 		fp := testProgPath(t, "testrerecord")
 		_, err := c.CreateBreakpoint(&api.Breakpoint{File: fp, Line: 10})
-		assertNoError(err, t, "CreateBreakpoin")
+		assertNoError(err, t, "CreateBreakpoint")
 
 		gett := func() int {
 			state := <-c.Continue()
@@ -2531,7 +2531,7 @@ func TestToggleBreakpointRestart(t *testing.T) {
 }
 
 func TestStopServerWithClosedListener(t *testing.T) {
-	// Checks that the error erturned by listener.Accept() is ignored when we
+	// Checks that the error returned by listener.Accept() is ignored when we
 	// are trying to shutdown. See issue #1633.
 	if testBackend == "rr" || buildMode == "pie" {
 		t.Skip("N/A")
@@ -3000,7 +3000,7 @@ func TestClientServer_breakpointOnFuncWithABIWrapper(t *testing.T) {
 	protest.AllowRecording(t)
 	withTestClient2("math", t, func(c service.Client) {
 		bp, err := c.CreateBreakpoint(&api.Breakpoint{FunctionName: "runtime.schedinit"})
-		assertNoError(err, t, "CreateBreakpoin()")
+		assertNoError(err, t, "CreateBreakpoint()")
 		t.Log(bp)
 
 		found := false
